var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { accounts, Config } from '@cee-eng/hydrajs';
import { LoginModal } from '@rh-support/components';
import { getApiResourceObject, setSecuredSupport, setStrataHeaders } from '@rh-support/utils';
import isEmpty from 'lodash/isEmpty';
import React, { useEffect, useState } from 'react';
import { GlobalMetadataContextProvider, GlobalMetadataDispatchContext } from './context/GlobalMetadataContext';
import { fetchAccountManagers, fetchLoggedInUser, fetchLoggedInUsersAccount, fetchManagedAccounts, fetchUserPreferences, GlobalMetadataReducerConstants, loadPCMConfig, setLoggedInUserJwtToken, } from './reducers/GlobalMetadataReducer';
function GlobalContextMetadataWrapper() {
    const [showReLoginModal, setShowReLoginModal] = useState(false);
    const [showSessionExpiredModal, setShowSessionExpiredModal] = useState(false);
    const dispatchToGlobalMetadataReducer = React.useContext(GlobalMetadataDispatchContext);
    // Configuring callbacks to show modals in case of auth logout or session expiry
    useEffect(() => {
        const init = () => __awaiter(this, void 0, void 0, function* () {
            /** @type { import("@rhcp/primer") } */
            const { session } = yield window.portal.primer.onReady();
            session.on('AuthLogout', () => setShowReLoginModal(true));
            ['AuthRefreshError', 'TokenExpired'].forEach((eventName) => session.on(eventName, () => {
                if (!session.isAuthenticated()) {
                    setShowSessionExpiredModal(true);
                }
            }));
        });
        init();
    }, []);
    const loadGlobalMetadata = (loggedInUserJwtToken) => {
        setLoggedInUserJwtToken(dispatchToGlobalMetadataReducer, loggedInUserJwtToken);
        /**
         * Even GS4 users can use strata's normal user and account endpoints and thus fetching them before hand. This improves the load time by 4 seconds
         */
        loadPCMConfig(dispatchToGlobalMetadataReducer).then((pcmConfig) => {
            fetchLoggedInUser(dispatchToGlobalMetadataReducer, loggedInUserJwtToken, pcmConfig);
        });
        fetchUserPreferences(dispatchToGlobalMetadataReducer, loggedInUserJwtToken);
        fetchManagedAccounts(dispatchToGlobalMetadataReducer, loggedInUserJwtToken);
        fetchAccountManagers(dispatchToGlobalMetadataReducer, loggedInUserJwtToken);
        fetchLoggedInUsersAccount(dispatchToGlobalMetadataReducer, loggedInUserJwtToken).then((loggedInUserAccount) => {
            setSecuredSupport(loggedInUserAccount === null || loggedInUserAccount === void 0 ? void 0 : loggedInUserAccount.secureSupport);
            if (loggedInUserAccount === null || loggedInUserAccount === void 0 ? void 0 : loggedInUserAccount.secureSupport) {
                Config.setUserConfig({ isLoggedInAccountGS4: true });
                const element = document.getElementById('rh-support-main');
                element && element.classList.add('support-secured');
            }
        });
    };
    useEffect(() => {
        const loggedInUserJwtToken = window.sessionjs.getToken();
        const getAccountNumber = () => __awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            //  Get account number from SFDC if token doesn't have it
            try {
                const account = yield accounts.getDefaultAccount();
                dispatchToGlobalMetadataReducer({
                    type: GlobalMetadataReducerConstants.setLoggedInUsersAccountNumber,
                    payload: { loggedInUsersAccountNumber: getApiResourceObject(account.accountNumber, false, false) },
                });
                loggedInUserJwtToken.account_number = account.accountNumber;
                setStrataHeaders((_a = window.app) !== null && _a !== void 0 ? _a : 'Portal Case Management', account.accountNumber);
                loadGlobalMetadata(loggedInUserJwtToken);
            }
            catch (e) {
                (_b = window.sessionjs) === null || _b === void 0 ? void 0 : _b.reportProblem(e, {
                    tags: {
                        portal_app: window.app || 'Portal Case Management',
                        error_effect: 'PCM - App wide error',
                    },
                    fingerprint: 'PCM - App wide error',
                    extra: { errorDetails: `App wide error due to getAccountNumber with status ${e === null || e === void 0 ? void 0 : e.status}` },
                });
                dispatchToGlobalMetadataReducer({
                    type: GlobalMetadataReducerConstants.setLoggedInUsersAccountNumber,
                    payload: { loggedInUsersAccountNumber: getApiResourceObject(null, false, true, e === null || e === void 0 ? void 0 : e.message, e) },
                });
            }
        });
        isEmpty(loggedInUserJwtToken.account_number) ? getAccountNumber() : loadGlobalMetadata(loggedInUserJwtToken);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [dispatchToGlobalMetadataReducer]);
    const login = () => {
        window.sessionjs.login();
        setShowReLoginModal(false);
        setShowReLoginModal(false);
    };
    return (React.createElement(React.Fragment, null,
        React.createElement(LoginModal, { isOpen: showReLoginModal, title: 'Welcome back', login: login, uniqueid: 'se-relogin-modal' }),
        React.createElement(LoginModal, { isOpen: showSessionExpiredModal, login: login, title: 'Session inactive', content: 'You have been logged out due to inactivity.', uniqueid: 'se-session-expired-description' })));
}
export const GlobalContextWrapper = (props) => (React.createElement(GlobalMetadataContextProvider, null,
    props.children,
    React.createElement(GlobalContextMetadataWrapper, null)));
