var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { accounts } from '@cee-eng/hydrajs';
import { Button, Flex, FlexItem, MenuToggle, Select, SelectList, SelectOption, TextInputGroup, TextInputGroupMain, TextInputGroupUtilities, } from '@patternfly/react-core';
import InfoCircleIcon from '@patternfly/react-icons/dist/js/icons/info-circle-icon';
import TimesCircleIcon from '@patternfly/react-icons/dist/js/icons/times-circle-icon';
import { LoadingIndicator, useFetch } from '@rh-support/components';
import isEmpty from 'lodash/isEmpty';
import isNull from 'lodash/isNull';
import isUndefined from 'lodash/isUndefined';
import uniqBy from 'lodash/uniqBy';
import React, { useEffect, useMemo, useRef, useState } from 'react';
import { Trans, useTranslation } from 'react-i18next';
import { sortAccountsByQuery } from '../../utils';
const defaultProps = {
    id: '',
    className: '',
    suggestBookmarkAccounts: true,
    canBookmarkAccount: false,
    bookmarkedAccounts: [],
    selectedAccounts: [],
    excludeAccounts: [],
    disabled: false,
    title: 'Account Selector',
    placeholder: 'Search for an account',
    emptyListLabel: 'No results found',
    maxResults: 20,
    useCache: true,
    paginate: true,
    delay: 300,
    multiple: false,
    isInValid: false,
    restrictedOnSubscriptionAbuse: false,
};
const getDisplayName = (account) => {
    if (!account) {
        return '';
    }
    return account.accountNumber
        ? account.name
            ? `${account.name} (${account.accountNumber})`
            : account.accountNumber
        : '';
};
function AccountSelectorInternal(props) {
    const { request, isFetching } = useFetch(accounts.getAccounts, { isAbortable: true });
    const [items, setItems] = useState([]);
    const [selectedItems, setSelectedItems] = useState([]);
    const [isOpen, setIsOpen] = useState(false);
    const [isQueryChanged, setIsQueryChanged] = useState(false);
    const [query, setQuery] = useState('');
    const [focusedItemIndex, setFocusedItemIndex] = useState(null);
    const textInputRef = useRef();
    const inputGroupRef = useRef();
    const { t } = useTranslation();
    const bookmarkedAccountsDeduped = uniqBy(props.bookmarkedAccounts, (b) => b.accountNumber);
    const pageSize = 20;
    const [resultSize, setResultSize] = useState(pageSize);
    const setQueryLabel = (selectedItems) => {
        const item = !isEmpty(selectedItems) && !props.multiple ? selectedItems[0] : {};
        setQuery(getDisplayName(item));
    };
    const itemsToRender = useMemo(() => (isEmpty(items) ? bookmarkedAccountsDeduped : items.slice(0, props.paginate ? resultSize : items.length)), [items, bookmarkedAccountsDeduped, props.paginate, resultSize]);
    useEffect(() => {
        if (!props.multiple) {
            const selectedItem = (props.selectedAccounts || [])[0];
            selectedItem && selectedItem.accountNumber && setSelectedItems(props.selectedAccounts || []);
        }
        else {
            setSelectedItems(props.selectedAccounts || []);
        }
    }, [props.selectedAccounts, props.multiple]);
    useEffect(() => {
        setQueryLabel(selectedItems);
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [selectedItems, props.multiple]);
    const onDisplayMoreClick = (e) => {
        e.stopPropagation();
        setResultSize((pre) => Math.min(pre + pageSize, items.length));
        setIsOpen(true);
    };
    const dropdownOptions = useMemo(() => {
        if (isFetching) {
            return (React.createElement("div", { key: "searching", className: "pf-v5-u-px-md pf-v5-u-py-sm" },
                React.createElement(Trans, null, "Searching...")));
        }
        if (isQueryChanged && isEmpty(items)) {
            return (React.createElement("div", { key: "no-results", className: "pf-v5-u-px-md pf-v5-u-py-sm" },
                React.createElement(Trans, null, "No results found")));
        }
        return [
            ...itemsToRender.map((item, index) => (React.createElement(SelectOption, { isFocused: focusedItemIndex === index, key: index, value: item, hasCheckbox: props.multiple, isSelected: selectedItems.some((account) => item.accountNumber === account.accountNumber) }, props.restrictedOnSubscriptionAbuse && item.subscriptionAbuse ? (React.createElement(Flex, { justifyContent: { default: 'justifyContentSpaceBetween' } },
                React.createElement(FlexItem, { className: "form-instructions form-invalid" }, getDisplayName(item)),
                React.createElement(FlexItem, { className: "form-instructions form-invalid pf-v5-u-text-nowrap pf-v5-u-pr-sm" },
                    React.createElement(InfoCircleIcon, null),
                    " ",
                    React.createElement(Trans, null, "Subscription abuse")))) : (React.createElement("span", null, getDisplayName(item)))))),
            ...(resultSize < items.length
                ? [
                    React.createElement("div", { className: "pf-v5-c-divider", role: "separator", key: "separator" }),
                    React.createElement(SelectOption, { key: 'diplay-more-option', onClick: onDisplayMoreClick, value: 'display-more' },
                        React.createElement(Flex, { justifyContent: { default: 'justifyContentCenter' } },
                            React.createElement(FlexItem, { className: '"pf-v5-c-button pf-m-link pf-m-inline' },
                                React.createElement(Trans, null, "Display additional results")))),
                ]
                : []),
        ];
    }, 
    // eslint-disable-next-line react-hooks/exhaustive-deps
    [items, bookmarkedAccountsDeduped, isFetching, itemsToRender, isQueryChanged]);
    const fetchAccounts = (query) => __awaiter(this, void 0, void 0, function* () {
        if (isEmpty(query)) {
            return;
        }
        const fields = ['accountNumber', 'accountId', 'name', 'subscriptionAbuse'].join(',');
        // Initialize Params
        let params = {
            fields,
            limit: 60,
            accountNumberNotNull: true,
        };
        let queryKey;
        // query as number is a hack to get around TS, isNaN can take a string but it was throwing error here
        if (isNaN(query)) {
            params.nameLike = query;
            queryKey = 'name';
        }
        else {
            params.accountNumberLike = query;
            queryKey = 'accountNumber';
        }
        const queryParams = params;
        const response = request && (yield request(queryParams));
        const options = response && response.items && response.items.length ? response.items : [];
        const sortedOptions = sortAccountsByQuery(options, query, queryKey);
        setItems(sortedOptions);
    });
    const onOuterClick = () => {
        setQueryLabel(props.selectedAccounts || []);
        setSelectedItems(props.selectedAccounts || []);
    };
    useEffect(() => {
        const handleClickOutside = (event) => {
            if (inputGroupRef.current && !inputGroupRef.current.contains(event.target)) {
                onOuterClick();
            }
        };
        document.addEventListener('mousedown', handleClickOutside);
        return () => {
            document.removeEventListener('mousedown', handleClickOutside);
        };
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [selectedItems, props.selectedAccounts]);
    const onMultiAccountSelection = (selection) => {
        let list = [];
        if (selectedItems.some((item) => item.accountNumber === selection.accountNumber)) {
            list = selectedItems.filter((item) => item.accountNumber !== selection.accountNumber);
        }
        else {
            list = [...props.selectedAccounts, selection];
        }
        setSelectedItems(list);
        props.onSelect && props.onSelect(list);
    };
    const onSingleAccountSelection = (selection) => {
        var _a;
        setSelectedItems([selection]);
        props.onSelect && props.onSelect([selection]);
        setIsOpen(false);
        (_a = textInputRef.current) === null || _a === void 0 ? void 0 : _a.blur();
    };
    const onFilter = (_event, value) => {
        setQuery(value);
        setIsQueryChanged(!isEmpty(value));
        fetchAccounts(value);
        setResultSize(pageSize);
        setFocusedItemIndex(null);
    };
    const onToggleClick = () => {
        setIsOpen((pre) => !pre);
    };
    const onClearSelection = (e) => {
        var _a;
        e.stopPropagation();
        setIsOpen(true);
        setSelectedItems([]);
        setItems([]);
        setIsQueryChanged(false);
        (_a = textInputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    };
    const onSelect = (selection) => {
        if (selection === 'display-more' || isUndefined(selection) || isNull(selection))
            return;
        props.multiple ? onMultiAccountSelection(selection) : onSingleAccountSelection(selection);
    };
    const handleMenuArrowKeys = (key) => {
        let indexToFocus;
        if (isOpen) {
            if (key === 'ArrowUp') {
                // When no index is set or at the first index, focus to the last, otherwise decrement focus index
                if (focusedItemIndex === null || focusedItemIndex === 0) {
                    indexToFocus = itemsToRender.length - 1;
                }
                else {
                    indexToFocus = focusedItemIndex - 1;
                }
            }
            if (key === 'ArrowDown') {
                // When no index is set or at the last index, focus to the first, otherwise increment focus index
                if (focusedItemIndex === null || focusedItemIndex === itemsToRender.length - 1) {
                    indexToFocus = 0;
                }
                else {
                    indexToFocus = focusedItemIndex + 1;
                }
            }
            setFocusedItemIndex(indexToFocus);
        }
    };
    const onInputKeyDown = (event) => {
        const focusedItem = focusedItemIndex ? itemsToRender[focusedItemIndex] : itemsToRender[0];
        switch (event.key) {
            // Select the first available option
            case 'Enter':
                if (!isOpen) {
                    setIsOpen((pre) => !pre);
                }
                else if (isOpen) {
                    onSelect(focusedItem);
                }
                break;
            case 'Escape':
                setIsOpen(false);
                break;
            case 'ArrowUp':
            case 'ArrowDown':
                event.preventDefault();
                handleMenuArrowKeys(event.key);
                break;
        }
    };
    const toggle = (toggleRef) => (React.createElement(MenuToggle, { innerRef: toggleRef, variant: "typeahead", onClick: onToggleClick, isExpanded: isOpen, isFullWidth: true, isDisabled: props.disabled },
        React.createElement(TextInputGroup, { isPlain: true, innerRef: inputGroupRef },
            React.createElement(TextInputGroupMain, { value: query, role: "combobox", onClick: onToggleClick, onKeyDown: onInputKeyDown, onChange: onFilter, placeholder: t(props.placeholder || ''), isExpanded: isOpen, innerRef: textInputRef, "aria-label": `select${props.multiple ? ' multi' : ''} typeahead listbox`, "aria-controls": "account-selector-dropdown" }),
            React.createElement(TextInputGroupUtilities, null, !isEmpty(query) && (React.createElement(Button, { variant: "plain", onClick: onClearSelection, isDisabled: isFetching, "aria-label": t('Clear') }, isFetching ? React.createElement(LoadingIndicator, { show: true, size: "sm" }) : React.createElement(TimesCircleIcon, { "aria-hidden": true })))))));
    return (React.createElement(Select, { "data-tracking-id": "account-selector-dropdown", isOpen: isOpen, onOpenChange: () => setIsOpen(false), id: props.id, toggle: toggle, popperProps: { direction: 'down', enableFlip: false }, onSelect: (_e, v) => onSelect(v), selected: selectedItems, isScrollable: true },
        React.createElement(SelectList, null, dropdownOptions)));
}
AccountSelectorInternal.defaultProps = defaultProps;
export { AccountSelectorInternal };
