import './embeddedServiceChat.css';
import { Button, ButtonVariant, Popover, PopoverPosition, Spinner } from '@patternfly/react-core';
import ExclamationCircleIcon from '@patternfly/react-icons/dist/js/icons/exclamation-circle-icon';
import React, { useRef, useState } from 'react';
import { Trans, useTranslation } from 'react-i18next';
import { FeatureAnnouncementKeys, NewFeaturePopoverAnnouncement, useChatInit } from '../..';
import { ChatSVGIcon } from './ChatSVGIcon';
export const EmbeddedServiceChat = () => {
    const componentRef = useRef(null);
    const { loadingChat, isChatStarted, onStartChat, hasChatDomainsBlocked, hasBlockedByBrowser, chatServiceNotAvailable, hasBlockedByCookie, } = useChatInit();
    const [isBlockedErrorBoxVisible, setIsBlockedErrorBoxVisible] = useState(true);
    const [chatClicked, setChatClicked] = useState(false);
    const { t } = useTranslation();
    const shouldClose = () => {
        setIsBlockedErrorBoxVisible(false);
    };
    const shouldOpen = () => {
        setIsBlockedErrorBoxVisible(true);
    };
    const chatErrorMessagePopover = (param) => (React.createElement("div", { className: "chatButton chatError", id: "chat-blocked-popover-selector" },
        React.createElement(Popover, { "aria-label": t('Cannot connect to chat support'), alertSeverityVariant: 'danger', position: PopoverPosition.top, hasAutoWidth: true, maxWidth: '420px', headerIcon: React.createElement(ExclamationCircleIcon, { className: "pf-v5-u-danger-color-100" }), headerComponent: "h1", headerContent: React.createElement(Trans, null, "Cannot connect to chat support"), bodyContent: param === 'cookie' ? (React.createElement("p", { className: "pf-v5-u-px-md" },
                React.createElement(Trans, null,
                    "Accept functional cookies in your",
                    ' ',
                    React.createElement(Button, { variant: ButtonVariant.link, isInline: true, onClick: (e) => {
                            e.preventDefault();
                            document.querySelector('#teconsent a[role="link"]').click();
                        } }, "cookie preferences"),
                    ' ',
                    "to enable the Red Hat Chat Support, then refresh page."))) : (React.createElement("p", { className: "pf-v5-u-px-md" },
                React.createElement(Trans, null, "There are multiple problems that can cause this error."),
                React.createElement("br", null),
                React.createElement("a", { href: `https://access.redhat.com/articles/313583#${hasBlockedByBrowser
                        ? 'troubleshoot_browser'
                        : hasChatDomainsBlocked
                            ? 'troubleshoot_network'
                            : ''}`, target: "_blank", rel: "noreferrer noopener" },
                    React.createElement(Trans, null, "See a list of possible causes.")))), isVisible: isBlockedErrorBoxVisible, shouldClose: shouldClose, shouldOpen: shouldOpen },
            React.createElement(Button, { variant: ButtonVariant.link, className: "pf-v5-u-m-0 pf-v5-u-p-0" },
                React.createElement(ChatSVGIcon, null)))));
    if (chatServiceNotAvailable)
        return React.createElement(React.Fragment, null);
    return loadingChat ? (React.createElement("div", { className: "chatButton" },
        React.createElement(Spinner, { diameter: "28px", className: "pf-v5-u-m-xs" }))) : hasBlockedByCookie && chatClicked && document.querySelector('#teconsent a[role="link"]') !== null ? (chatErrorMessagePopover('cookie')) : (hasBlockedByBrowser || hasChatDomainsBlocked) && chatClicked ? (chatErrorMessagePopover()) : !isChatStarted ? (React.createElement("div", { className: "chatButton", onClick: () => {
            onStartChat();
            setChatClicked(true);
        }, "data-tracking-id": "embedded-service-chat", ref: componentRef, id: "chat-bot-wrapper" },
        React.createElement(ChatSVGIcon, null),
        React.createElement(NewFeaturePopoverAnnouncement, { "aria-label": t('Support now has a chatbot (beta). Try it if you need help with a case.'), featureName: FeatureAnnouncementKeys.CHAT_BOT, sectionRef: componentRef, bodyContent: React.createElement("div", null,
                React.createElement(Trans, null, "Support now has a chatbot (beta). Try it if you need help with a case.")), triggerRef: () => document.getElementById('chat-bot-wrapper') }))) : (React.createElement(React.Fragment, null));
};
