var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import './hostnameAwarenessModal.css';
import { accounts } from '@cee-eng/hydrajs';
import { Button, Checkbox, Modal, ModalVariant, Spinner, Switch, Tooltip } from '@patternfly/react-core';
import InfoIcon from '@patternfly/react-icons/dist/js/icons/info-circle-icon';
import { useFetch } from '@rh-support/components';
import { ability, CaseListFields, resourceActions, resources } from '@rh-support/user-permissions';
import React, { useContext, useEffect, useState } from 'react';
import { Trans } from 'react-i18next';
import { GlobalMetadataDispatchContext, useGlobalStateContext } from '../../context/GlobalMetadataContext';
import { useUserPreferences } from '../../hooks';
import { updateShareHostnameWithRHTState } from '../../reducers/GlobalMetadataReducer';
export const HostnameAwarenessModal = () => {
    // Function to fetch original data
    const { getHostnamesVisibilityObj, updateShowHostnamesCount } = useUserPreferences();
    // Setting State for original data value which are used to open/finalize close modal
    const [originalViewedCountValue, setViewedCountValue] = useState(undefined);
    const [doNotShowModal, setDoNotShowModal] = useState(0);
    const [isModalOpen, setIsModalOpen] = useState(false);
    const [isHostnamesChecked, setisHostnamesChecked] = useState(false);
    const { globalMetadataState: { loggedInUsersAccount }, } = useGlobalStateContext();
    const dispatchToGlobalMetadataReducer = useContext(GlobalMetadataDispatchContext);
    const accountNumber = loggedInUsersAccount.data.accountNumber;
    const { request: updateHostnameDefault, isFetching: isFetchingUpdateHostnameDefault } = useFetch(accounts.updateIsSharingHostname);
    //Do not show modal if user cannot share hostnames.
    const canUseHostName = ability.can(resourceActions.PATCH, resources.CASE_CREATE, CaseListFields.HOSTNAME);
    useEffect(() => {
        if (loggedInUsersAccount.isFetching)
            return;
        let localOriginalViewedCountValue;
        let localDoNotShowModal;
        const userOriginalHostnamesCount = () => __awaiter(void 0, void 0, void 0, function* () {
            try {
                const originalHostnameVisibilityObj = yield getHostnamesVisibilityObj();
                if (!originalHostnameVisibilityObj)
                    return;
                const parsedVisibilityObj = JSON.parse(originalHostnameVisibilityObj);
                // updating space takes time, here we define a lcal variable to immidiatly use the value
                localOriginalViewedCountValue = parsedVisibilityObj.shownCount;
                localDoNotShowModal = parsedVisibilityObj.doNotShow;
                setViewedCountValue(parsedVisibilityObj.shownCount);
                setDoNotShowModal(parsedVisibilityObj.doNotShow);
            }
            catch (error) {
                console.log(error);
            }
        });
        const userOriginalHostnameValue = () => __awaiter(void 0, void 0, void 0, function* () {
            var _a;
            setisHostnamesChecked((_a = loggedInUsersAccount.data) === null || _a === void 0 ? void 0 : _a.shareHostnameWithRHT);
        });
        const init = () => __awaiter(void 0, void 0, void 0, function* () {
            yield userOriginalHostnamesCount();
            userOriginalHostnameValue();
            //Do not show modal if user is already sharing hostnames, has seen the modal more than twice, or opted to not show it again
            if (canUseHostName && localDoNotShowModal !== 1 && localOriginalViewedCountValue < 2) {
                setIsModalOpen(true);
            }
        });
        init();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [loggedInUsersAccount.isFetching]);
    // To handle modal close
    const onCloseModal = () => __awaiter(void 0, void 0, void 0, function* () {
        if (isFetchingUpdateHostnameDefault)
            return;
        try {
            const updatedCountValue = (originalViewedCountValue || 0) + 1;
            updateShowHostnamesCount({ shownCount: updatedCountValue, doNotShow: doNotShowModal });
            setIsModalOpen(false);
        }
        catch (error) {
            console.log(error);
        }
    });
    // for hostnames swich
    const onHostnameSwitchChange = () => __awaiter(void 0, void 0, void 0, function* () {
        try {
            yield updateHostnameDefault(!isHostnamesChecked, accountNumber);
            // update state
            updateShareHostnameWithRHTState(dispatchToGlobalMetadataReducer, loggedInUsersAccount.data, true);
            setisHostnamesChecked(!isHostnamesChecked);
        }
        catch (error) {
            console.log(error);
        }
    });
    //for the checkbox
    const onDoNotAskAgain = () => {
        try {
            setDoNotShowModal(1);
            const updateObjValue = { shownCount: originalViewedCountValue, doNotShow: 1 };
            updateShowHostnamesCount(updateObjValue);
        }
        catch (error) {
            console.log(error);
        }
    };
    const shareHostnamesClarificationCopy = (React.createElement("div", null,
        "This is ",
        React.createElement("b", null, "not required"),
        ". We will not capture any information unless you choose to opt in."));
    const modalBody = () => {
        return (React.createElement(React.Fragment, null,
            React.createElement(Switch, { label: "Share hostnames", isChecked: isHostnamesChecked, onChange: onHostnameSwitchChange, className: "push-top-narrow" }),
            React.createElement(Tooltip, { content: shareHostnamesClarificationCopy, position: "right" },
                React.createElement(InfoIcon, { className: "pf-v5-u-ml-sm hostnameInfoIcon" })),
            isFetchingUpdateHostnameDefault && (React.createElement(Spinner, { size: "lg", className: "pf-v5-u-ml-sm hostnameSpinner", "aria-label": "Hostname loading" }))));
    };
    return (React.createElement(Modal, { variant: ModalVariant.medium, title: "Share hostnames with Red Hat?", isOpen: isModalOpen, onClose: onCloseModal, actions: [
            React.createElement(Button, { "data-tracking-id": "close-hostname-modal", key: "close", variant: "primary", onClick: onCloseModal, isDisabled: isFetchingUpdateHostnameDefault }, "Close"),
            React.createElement("div", { className: "dontAskCheckbox" },
                React.createElement(Checkbox, { isChecked: !!doNotShowModal, label: "Don't ask me again", id: "dont-ask-again", "data-tracking-id": "dont-ask-again-hostname-modal", onChange: onDoNotAskAgain })),
        ] },
        React.createElement("div", null,
            React.createElement(Trans, null, "Red Hat Support cannot currently access hostnames that have been entered on a case. You can share this information at any time to improve your support experience, or you can ignore this.")),
        modalBody()));
};
