var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import './CloseCaseModal.scss';
import { Button, ButtonVariant, Form, FormGroup, FormHelperText, HelperText, HelperTextItem, Modal, ModalVariant, TextArea, } from '@patternfly/react-core';
import { Select, SelectOption } from '@patternfly/react-core/deprecated';
import isEmpty from 'lodash/isEmpty';
import React, { useState } from 'react';
import { Trans, useTranslation } from 'react-i18next';
const resolutionsWithDescription = ['Other'];
const resolutionWithoutDescription = [
    'Red Hat solved my issue or reviewed my request',
    'The issue has been self-solved',
    "I'm not experiencing the issue anymore",
];
const resolutionOptions = [...resolutionWithoutDescription, ...resolutionsWithDescription];
export function CloseCaseModal(props) {
    const { t } = useTranslation();
    const [showTextArea, setShowTextArea] = useState(false);
    const [selectedResolution, setSelectedResolution] = useState('');
    const [resolutionDescription, setResolutionDescription] = useState('');
    const [showDropdown, setShowDropdown] = useState(false);
    const onDropdownToggle = (toggle) => setShowDropdown(toggle);
    const [showValidationError, setShowValidationError] = useState(false);
    const isCaseListPage = !props.caseNumber;
    const onResolutionChange = (event, resolution) => {
        setSelectedResolution(resolution);
        setShowValidationError(false);
        resolutionsWithDescription.includes(resolution) ? setShowTextArea(true) : setShowTextArea(false);
        onDropdownToggle(false);
    };
    const getCommentBody = () => {
        return `**Reason for closing case:** \n${selectedResolution}${resolutionsWithDescription.includes(selectedResolution) ? `. ${resolutionDescription}` : ''}`;
    };
    // To check for required fields
    const checkForRequiredFields = () => {
        let isValid = false;
        if (selectedResolution) {
            isValid = resolutionsWithDescription.includes(selectedResolution)
                ? resolutionDescription
                    ? true
                    : false
                : true;
        }
        setShowValidationError(isValid ? false : true);
        return isValid;
    };
    const onSubmit = () => __awaiter(this, void 0, void 0, function* () {
        if (!checkForRequiredFields())
            return;
        props.onConfirm(getCommentBody());
    });
    const onDescriptionChange = (description) => {
        setShowValidationError(false);
        setResolutionDescription(description);
    };
    const isResolutionDescEmpty = showTextArea && isEmpty(resolutionDescription === null || resolutionDescription === void 0 ? void 0 : resolutionDescription.trim());
    return (React.createElement(Modal, { id: "case-close-modal", title: t(isCaseListPage ? 'Do you want to close the selected cases?' : 'Do you want to close this case?'), "aria-describedby": "case-close-modal", isOpen: true, onClose: props.onClose, showClose: true, actions: [
            React.createElement(Button, { key: "submit-description", variant: ButtonVariant.primary, onClick: onSubmit, isLoading: props.isUpdating, isDisabled: isResolutionDescEmpty || showValidationError || props.isUpdating, "data-tracking-id": "close-case-description-modal-submit" },
                React.createElement(Trans, null, "Close case")),
            React.createElement(Button, { key: "close-modal", variant: ButtonVariant.secondary, onClick: props.onClose, isDisabled: props.isUpdating, "data-tracking-id": "close-case-description-modal-cancel" },
                React.createElement(Trans, null, "Cancel")),
        ], variant: ModalVariant.medium },
        React.createElement("div", { className: "pf-v5-u-mb-md" }, !isCaseListPage ? (React.createElement("p", null,
            React.createElement(Trans, null,
                "Confirming will set the status of this case ",
                React.createElement("strong", null, "closed"),
                ". You can still view the case after it closes."))) : (React.createElement(React.Fragment, null,
            React.createElement("p", null,
                React.createElement(Trans, null,
                    "Confirming will set the status of every case to ",
                    React.createElement("strong", null, "closed"),
                    ". You can still view a case after closing.")),
            React.createElement("p", null,
                React.createElement(Trans, null, "This action will also reset the currently selected filters to default state."))))),
        React.createElement(Form, { className: "close-case-modal-form" },
            React.createElement(FormGroup, { label: t('Resolution'), isRequired: true, fieldId: "case-resolution" },
                React.createElement(FormHelperText, null,
                    React.createElement(HelperText, null,
                        isCaseListPage && !(showValidationError && !selectedResolution) && (React.createElement(HelperTextItem, null,
                            React.createElement(Trans, null, "All of the selected cases will have the same resolution in bulk edit."))),
                        showValidationError && !selectedResolution && (React.createElement(HelperTextItem, { variant: "error", hasIcon: true },
                            React.createElement(Trans, null, "Required field"))))),
                React.createElement(Select, { "aria-label": t('Select an option that best fits'), id: "case-resolution", selections: selectedResolution, onSelect: onResolutionChange, isOpen: showDropdown, isDisabled: props.isUpdating, menuAppendTo: document.body, validated: showValidationError && !selectedResolution ? 'error' : 'default', placeholderText: t('Select an option that best fits'), onToggle: (_event, toggle) => onDropdownToggle(toggle) }, resolutionOptions.map((option, index) => (React.createElement(SelectOption, { key: index, value: option },
                    React.createElement(Trans, null, option)))))),
            showTextArea && (React.createElement(FormGroup, { label: t('Please describe your resolution'), type: "text", isRequired: true, fieldId: "close-case-description" },
                React.createElement(TextArea, { validated: showValidationError && !resolutionDescription ? 'error' : 'default', isRequired: true, id: "close-case-description", name: "close-case-description", "aria-describedby": "close-case-description", value: resolutionDescription, placeholder: t('Please describe your resolution to help us better understand.'), onChange: (_event, description) => onDescriptionChange(description), isDisabled: props.isUpdating, resizeOrientation: "vertical" }))))));
}
