var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { languageConst } from '@rh-support/components';
import { CacheUtilsService, getCookieValue } from '@rh-support/utils';
import i18n from 'i18next';
import localForageCase from 'localforage';
import isEmpty from 'lodash/isEmpty';
import React, { useEffect, useState } from 'react';
import { I18nextProvider, initReactI18next } from 'react-i18next';
function getRhLocaleLang() {
    const cookieVal = (getCookieValue('rh_locale') || 'en_US').split('_')[0];
    return cookieVal && languageConst[cookieVal] ? cookieVal : 'en';
}
const initialTranslationContext = {
    setLang: undefined,
    fetchingTranslation: false,
};
export const SELECTED_TRANS_LANGUAGE = 'selected_trans_language';
export const cacheTrans = new CacheUtilsService(localForageCase, { name: SELECTED_TRANS_LANGUAGE });
export const GlobalTranslationContext = React.createContext(initialTranslationContext);
export function GlobalTranslationProvider(props) {
    const [lang, setLang] = useState(getRhLocaleLang());
    const [resources, setResource] = useState({ lang: '', translation: {} });
    const [fetchingResources, setFetchingResource] = useState(false);
    useEffect(() => {
        function getLang() {
            return __awaiter(this, void 0, void 0, function* () {
                try {
                    // Currently we give precedence to cookie value(rh_locale) that is set by portal team if it's not en_US,
                    // i.e if user selects the either ja or ko or zh_cn that particular language will be loaded
                    // our stored language will be ignored even if that user has some stored language
                    const value = yield cacheTrans.getWithFullKey(window.sessionjs.getUserInfo().username);
                    if (getRhLocaleLang() === 'en' && (value === null || value === void 0 ? void 0 : value.value) !== 'en') {
                        value && setLang(value.value);
                    }
                }
                catch (error) {
                    console.error(error);
                }
            });
        }
        getLang();
    }, []);
    i18n.use(initReactI18next).init({
        lng: lang || 'en',
        interpolation: {
            escapeValue: false,
        },
        resources: resources && resources.translation,
        react: {
            bindI18n: 'languageChanged loaded',
        },
        nsSeparator: ':::',
        keySeparator: '::',
        debug: false,
    });
    /*
     * Using translation has never been this fun
     * To use translation there are 2 way
     * 1. Using <Trans /> component
     * Let's try to translate "+3 more points"
     * import { Trans } from 'react-i18next';
     * <Trans>+{{more: props.more}} more points</Trans>
     * Trans component allow you to use it with links and different tags inside it
     * 2. You can also use t()
     * t('+{{more}} more points', {more: props.more})
     */
    const { fetchTrans } = props;
    useEffect(() => {
        if (resources && resources.translation[lang] && !isEmpty(resources.translation[lang].translation)) {
            return;
        }
        const setTranslationResource = (selectedLang) => __awaiter(this, void 0, void 0, function* () {
            setFetchingResource(true);
            try {
                const response = yield fetchTrans(selectedLang);
                setResource(response);
            }
            catch (error) {
                console.error('Error in setting up new language');
            }
            setFetchingResource(false);
        });
        setTranslationResource(lang);
    }, [lang, resources, fetchTrans]);
    return (React.createElement(GlobalTranslationContext.Provider, { value: { setLang, fetchingTranslation: fetchingResources } },
        React.createElement(I18nextProvider, { i18n: i18n }, props.children)));
}
