import { getConfigField, isCurrentDateAfterDate, isFutureDate, PCM_CONFIG_FIELD_TYPE } from '@rh-support/utils';
import isEmpty from 'lodash/isEmpty';
import { useContext, useMemo, useRef } from 'react';
import { GlobalMetadataDispatchContext, GlobalMetadataStateContext } from '../context/GlobalMetadataContext';
import { updateUserPreferences, UserPreferencesKeys } from '../reducers/GlobalMetadataReducer';
export var FeatureAnnouncementKeys;
(function (FeatureAnnouncementKeys) {
    FeatureAnnouncementKeys["SEND_NOTIFICATIONS"] = "sendNotifications";
    FeatureAnnouncementKeys["MARKDOWN_INLINE_IMAGES"] = "markdownInlineImages";
    FeatureAnnouncementKeys["CASE_TYPE_FILTER"] = "caseTypeFilter";
    FeatureAnnouncementKeys["SHARE_HOSTNAMES"] = "shareHostnamesWithRHT";
    FeatureAnnouncementKeys["CHAT_BOT"] = "chatBot";
})(FeatureAnnouncementKeys || (FeatureAnnouncementKeys = {}));
export function useFeatureAnnouncement(featureName) {
    const { globalMetadataState: { loggedInUserRights, hydraUserPreferences, pcmConfig }, } = useContext(GlobalMetadataStateContext);
    const globalMetadataDispatch = useContext(GlobalMetadataDispatchContext);
    const isCleanupScheduled = useRef(false);
    const newFeaturesList = useMemo(() => getConfigField(pcmConfig.data, 'newFeaturesList', PCM_CONFIG_FIELD_TYPE.JSON_ARRAY) || [], [pcmConfig.data]);
    const userFeatureAnnouncementPreferences = useMemo(() => {
        const featureAnnouncementsPreferences = (hydraUserPreferences.data || []).find((pref) => pref.key === UserPreferencesKeys.featureAnnouncement);
        return (featureAnnouncementsPreferences === null || featureAnnouncementsPreferences === void 0 ? void 0 : featureAnnouncementsPreferences.value) ? JSON.parse(featureAnnouncementsPreferences.value) : {};
    }, [hydraUserPreferences.data]);
    const isFeatureAnnouncementVisibleFn = () => {
        if (!featureName)
            return;
        let isFeatureAnnouncementVisible = false;
        let featureText = '';
        const featureConfig = (newFeaturesList || []).find((feature) => feature.name === featureName);
        if (!featureConfig) {
            !isEmpty(pcmConfig.data) &&
                !isCleanupScheduled.current &&
                setTimeout(() => cleanUpFeatureDataInUserPreference(), 2000); // to avoid bad states we do the cleanup after a timeout
            return { isFeatureAnnouncementVisible, featureText };
        }
        const { isLive = true, visibilty = 'all', startDate = '', expireDate = '', featureInfoText = '', showCount = -1, } = featureConfig;
        const { shownCount = 0 } = userFeatureAnnouncementPreferences[featureName] || {};
        if (!isLive ||
            (visibilty === 'internal' && !loggedInUserRights.data.isInternal()) ||
            (showCount !== -1 && Number(shownCount) >= Number(showCount)) ||
            (startDate && isFutureDate(startDate)) ||
            (expireDate && isCurrentDateAfterDate(expireDate))) {
            isFeatureAnnouncementVisible = false;
        }
        else {
            featureText = featureInfoText;
            isFeatureAnnouncementVisible = true;
        }
        return { isFeatureAnnouncementVisible, featureText };
    };
    /**
     * If a feature is removed from the PCM config, then we can erase that data from the user preferences too
     */
    const cleanUpFeatureDataInUserPreference = () => {
        if (!featureName || hydraUserPreferences.isFetching || isCleanupScheduled.current)
            return;
        const allFeatures = userFeatureAnnouncementPreferences || {};
        const featureConfig = allFeatures[featureName];
        if (featureConfig) {
            isCleanupScheduled.current = true;
            delete allFeatures[featureName];
            try {
                updateUserPreferences(globalMetadataDispatch, loggedInUserRights.data.getSSOUsername(), [{ key: UserPreferencesKeys.featureAnnouncement, value: JSON.stringify(allFeatures) }], 'add');
            }
            catch (e) {
                console.error('Could not update feature config in user preferences');
            }
        }
    };
    const onFeatureDismiss = () => {
        if (!featureName || hydraUserPreferences.isFetching)
            return;
        const allFeatures = userFeatureAnnouncementPreferences || {};
        const featureConfig = allFeatures[featureName] || {};
        allFeatures[featureName] = {
            shownCount: Number((featureConfig === null || featureConfig === void 0 ? void 0 : featureConfig.shownCount) || 0) + 1,
        };
        try {
            updateUserPreferences(globalMetadataDispatch, loggedInUserRights.data.getSSOUsername(), [{ key: UserPreferencesKeys.featureAnnouncement, value: JSON.stringify(allFeatures) }], 'add');
        }
        catch (e) {
            console.error('Could not update feature config in user preferences');
        }
    };
    return { featureConfig: isFeatureAnnouncementVisibleFn(), onFeatureDismiss };
}
