var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { publicApi } from '@cee-eng/hydrajs';
import { useFetch } from '@rh-support/components';
export function useGroupedBookmarkApiCalls(username, bookmarkedGroupIds) {
    const { request: addMultipleBookmarks, isFetching: isAddingBookmark } = useFetch(publicApi.utilsBookmark.addMultipleBookmarks, { propgateErrors: true });
    const { request: removeASpecificBookmark, isFetching: isRemovingBookmark } = useFetch(publicApi.utilsBookmark.removeASpecificBookmark, { propgateErrors: true });
    const { request: removeWholeBookmark } = useFetch(publicApi.utilsBookmark.removeWholeBookmark, {
        propgateErrors: true,
    });
    const { request: updateBookmark, isFetching: isEditingBookmark } = useFetch(publicApi.utilsBookmark.updateBookmark, { propgateErrors: true });
    const addBookmarksApiCall = (accounts, group) => __awaiter(this, void 0, void 0, function* () {
        return yield addMultipleBookmarks({
            namespace: { id: bookmarkedGroupIds.namespaceId },
            app: { id: bookmarkedGroupIds.appId },
            valueType: { id: bookmarkedGroupIds.valueTypeId },
            name: group,
            username,
            values: accounts.map((account) => ({ value: account.accountNumber })),
        });
    });
    const removeGroupAccount = (rootBookmarkId) => __awaiter(this, void 0, void 0, function* () {
        yield removeWholeBookmark(rootBookmarkId.toString());
    });
    const removeAccountApiCalls = (account) => __awaiter(this, void 0, void 0, function* () {
        const response = yield removeASpecificBookmark(account.rootBookmarkId.toString(), bookmarkedGroupIds.appId.toString(), account.bookmarkId.toString());
        // delete empty bookmark item with no value(account number) for data cleanup purpose
        if (response.values.length === 0) {
            removeWholeBookmark(response.id.toString());
        }
        return response;
    });
    const editBookmarkApiCall = (accounts, group, rootBookmarkID) => __awaiter(this, void 0, void 0, function* () {
        return yield updateBookmark({
            namespace: { id: bookmarkedGroupIds.namespaceId },
            app: { id: bookmarkedGroupIds.appId },
            valueType: { id: bookmarkedGroupIds.valueTypeId },
            username,
            name: group,
            values: accounts.map((account) => ({ value: account.accountNumber })),
        }, rootBookmarkID.toString());
    });
    return {
        isAddingBookmark,
        isRemovingBookmark,
        isEditingBookmark,
        addBookmarksApiCall,
        removeAccountApiCalls,
        removeGroupAccount,
        editBookmarkApiCall,
    };
}
