var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useContext } from 'react';
import { GlobalMetadataDispatchContext, GlobalMetadataStateContext } from '../';
import { updateUserPreferences, UserPreferencesKeys } from '../reducers';
export function useUserPreferences() {
    const { globalMetadataState: { loggedInUser, hydraUserPreferences }, } = useContext(GlobalMetadataStateContext);
    const globalMetadataDispatch = useContext(GlobalMetadataDispatchContext);
    const doesKeyExistWithSameValue = (key, value) => {
        const item = getKeyValue(key);
        return item && item === value;
    };
    const getKeyValue = (key) => {
        const item = hydraUserPreferences.data.find((pref) => pref.key === key);
        return item ? item.value : null;
    };
    const getHostnamesVisibilityObj = () => {
        return getKeyValue(UserPreferencesKeys.showHostnames);
    };
    const updateShowHostnamesCount = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.showHostnames, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [
            {
                key: UserPreferencesKeys.showHostnames,
                value: JSON.stringify({ shownCount: value.shownCount, doNotShow: value.doNotShow || 0 }),
            },
        ], 'add', true, true);
    });
    const getNewPreferenceTooltipSeenCount = () => {
        return getKeyValue(UserPreferencesKeys.showNewPreferenceTooltip);
    };
    const updateNewPreferenceTooltipSeenCount = (newCount) => __awaiter(this, void 0, void 0, function* () {
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [
            {
                key: UserPreferencesKeys.showNewPreferenceTooltip,
                value: newCount,
            },
        ], 'add', true, true);
    });
    const updateAutoRestoreSavedSearchPreference = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.autoRestoreSavedSearch, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.autoRestoreSavedSearch, value }], 'add', true, true);
    });
    const getAutoRestoreSavedSearchPreference = () => {
        return getKeyValue(UserPreferencesKeys.autoRestoreSavedSearch);
    };
    const getAutoRestoreLastSearchPreference = () => {
        return getKeyValue(UserPreferencesKeys.autoRestoreLastSearch);
    };
    const updateAutoRestoreLastSearchPreference = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.autoRestoreLastSearch, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.autoRestoreLastSearch, value }], 'add', true, true);
    });
    const getAutoSaveSelectedColumnsPreference = () => {
        return getKeyValue(UserPreferencesKeys.autoSaveSelectedColumns);
    };
    const updateAutoSaveSelectedColumnsPreference = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.autoSaveSelectedColumns, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.autoSaveSelectedColumns, value }], 'add', true, true);
    });
    const getCommentSignature = () => {
        return getKeyValue(UserPreferencesKeys.commentSignature);
    };
    const updateCommentSignature = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.commentSignature, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.commentSignature, value }], 'add', true, true);
    });
    const getShareHostNames = () => {
        return getKeyValue(UserPreferencesKeys.shareHostnames);
    };
    const updateShareHostNames = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.shareHostnames, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.shareHostnames, value }], 'add', true, true);
    });
    const getPreferredLanguage = () => {
        return getKeyValue(UserPreferencesKeys.preferredLanguage);
    };
    const updatePreferredLanguage = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.preferredLanguage, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.preferredLanguage, value }], 'add', true, true);
    });
    const getDefaultGroup = () => {
        return getKeyValue(UserPreferencesKeys.defaultGroups);
    };
    const updateDefaultGroup = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.defaultGroups, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.defaultGroups, value }], 'add', true, true);
    });
    const getCommentTypeFromPreference = () => {
        return getKeyValue(UserPreferencesKeys.commentType);
    };
    const updateCommentType = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.commentType, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.commentType, value }], 'add', true, true);
    });
    // Will return 1 if caseViewPref is set to internal.  If returning 0, it is assumed the user wants external view.  No value means has not been chosen.
    const getOriginalCaseView = () => {
        return getKeyValue(UserPreferencesKeys.caseViewInternal);
    };
    const updateOriginalCaseView = (value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(UserPreferencesKeys.caseViewInternal, value))
            return;
        yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key: UserPreferencesKeys.caseViewInternal, value }], 'add', true, true);
    });
    const updatePreferences = (key, value) => __awaiter(this, void 0, void 0, function* () {
        if (doesKeyExistWithSameValue(key, value))
            return;
        try {
            yield updateUserPreferences(globalMetadataDispatch, loggedInUser.data.ssoUsername, [{ key, value }], 'add', true, true);
        }
        catch (e) {
            throw e;
        }
    });
    const getPreferenceByKey = (key) => {
        return getKeyValue(key);
    };
    return {
        getHostnamesVisibilityObj,
        updateShowHostnamesCount,
        getNewPreferenceTooltipSeenCount,
        updateNewPreferenceTooltipSeenCount,
        updateCommentType,
        getCommentTypeFromPreference,
        getAutoRestoreSavedSearchPreference,
        updateAutoRestoreSavedSearchPreference,
        getAutoRestoreLastSearchPreference,
        updateAutoRestoreLastSearchPreference,
        getAutoSaveSelectedColumnsPreference,
        updateAutoSaveSelectedColumnsPreference,
        getCommentSignature,
        updateCommentSignature,
        getShareHostNames,
        updateShareHostNames,
        getPreferredLanguage,
        updatePreferredLanguage,
        getDefaultGroup,
        updateDefaultGroup,
        getOriginalCaseView,
        updateOriginalCaseView,
        updatePreferences,
        getPreferenceByKey,
    };
}
