import { IAccountNotificationAddresses } from '@cee-eng/hydrajs/@types/api/customEmail';
import { IBookmarkedAccounts } from '@cee-eng/hydrajs/@types/api/public/bookmarks';
import { ICaseGroup } from '@cee-eng/hydrajs/@types/api/public/caseGroups';
import { IAccount, IPartnerManagedAccount } from '@cee-eng/hydrajs/@types/models/account';
import { ISsoContact } from '@cee-eng/hydrajs/@types/models/contact';
import { IPreference } from '@cee-eng/hydrajs/@types/models/general';
import { IConfigurationResponse } from '@cee-eng/hydrajs/@types/models/maintenance';
import { ISEProductListParams } from '@cee-eng/hydrajs/@types/models/product';
import { IAction, IApiResponseDetails, IPortalJwtToken } from '@rh-support/types/shared';
import { UserAuth } from '@rh-support/user-permissions';
import { ITroubleshootProductResponse } from '@rh-support/utils';
import { MutableRefObject } from 'react';
export declare enum UserPreferencesKeys {
    caseSavedSearchFilters = "PCM-CaseSavedSearchFilters",
    commentType = "PCM-CommentType",
    mostRecentSearch = "PCM-MostRecentSearch",
    caseListSelectedColumns = "PCM-CaseListSelectedColumns",
    featureAnnouncement = "PCM-FeatureAnnouncement",
    autoRestoreSavedSearch = "PCM-AutoRestoreSavedSearch",
    autoRestoreLastSearch = "PCM-AutoRestoreLastSearch",
    autoSaveSelectedColumns = "PCM-AutoSaveSelectedColumns",
    commentSignature = "PCM-CommentSignature",
    shareHostnames = "PCM-ShareHostnames",
    preferredLanguage = "PCM-PreferredLanguage",
    defaultGroups = "PCM-DefaultGroup",
    showHostnames = "PCM-showHostName",
    showNewPreferenceTooltip = "PCM-prefToolTipVisibility",
    caseViewInternal = "PCM-caseViewInternal",
    partnershipLastestAcceptedLink = "PCM-PartnershipLastestAcceptedLink",
    partnershipLastestRejectedLink = "PCM-PartnershipLastestRejectedLink",
    userLastSavedABTest = "PCM-UserLastSavedABTest"
}
export declare const BOOKMARK_APPLICATION_NAME = "pcm";
export declare const BOOKMARK_NAME_SPACE = "customer-portal";
export declare const BOOKMARK_TYPE = "accountnumbers";
export interface IBookmark {
    rootBookmarkId: number;
    bookmarkGroupName: string;
    bookmarkId: number;
    accountNumber: string;
    name: string;
    isBookmarked: boolean;
    isBookmarkedAndHasGroup: boolean;
    subscriptionAbuse: boolean;
}
export declare enum FeatureFlagKey {
    tcSearch = "tcSearch"
}
export declare enum GlobalMetadataReducerConstants {
    setCaseTypes = "setCaseTypes",
    setCaseSeverities = "setCaseSeverities",
    setCaseStatuses = "setCaseStatuses",
    setCaseEntitlements = "setCaseEntitlements",
    setAllProducts = "setAllProducts",
    setLoggedInUsersAccount = "setLoggedInUsersAccount",
    setLoggedInUsersAccountNumber = "setLoggedInUsersAccountNumber",
    setLoggedInUser = "setLoggedInUser",
    setCaseLanguages = "setCaseLanguages",
    setCaseGroups = "setCaseGroups",
    setPcmConfig = "setPcmConfig",
    setLoggedInUserJwtToken = "setLoggedInUserJwtToken",
    setLoggedInUserRoles = "setLoggedInUserRoles",
    setManagedAccounts = "setManagedAccounts",
    setAccountManagers = "setAccountManagers",
    getBookmarkedAccounts = "getBookmarkedAccounts",
    updateGroupedBookmarks = "updateGroupedBookmarks",
    removeGroupedBookmarks = "removeGroupedBookmarks",
    getBookmarkedGroupAccounts = "getBookmarkedGroupAccounts",
    bookmarkAdded = "bookmarkAdded",
    bookmarkRemoved = "bookmarkRemoved",
    setInternalStatuses = "setInternalStatuses",
    setSbrGroups = "setSbrGroups",
    setUserPreferences = "setUserPreferences",
    toggleViewAsCustomer = "toggleViewAsCustomerFlag",
    setNavbarRef = "setNavbarRef",
    setHydraUserPreferences = "setHydraUserPreferences",
    updateFeatureFlag = "updateFeatureFlag",
    setAccountCustomEmails = "setAccountCustomEmails",
    setReferrerUrl = "setReferrerUrl",
    getNoclusteridreasons = "getNoclusteridreasons",
    setIsSharingHostnameswithRHt = "setIsSharingHostnameswithRHt",
    setCaseListTraditionalSupportAgreed = "setCaseListTraditionalSupportAgreed"
}
export type ICaseType = string;
export type ICaseSeverity = string;
export type ICaseStatus = string;
export interface IIntraction {
    time: Date;
    action: string;
    context: string[];
}
export interface IUserPreferences {
    isCaseListFilterPanelExanded?: boolean;
}
export type IFeatureFlags = {
    [k in keyof typeof FeatureFlagKey]?: boolean;
};
export interface IBookmarkedGroupIds {
    appId: number;
    namespaceId: number;
    valueTypeId: number;
}
export interface IGlobalMetadataState {
    allCaseTypes: IApiResponseDetails<ICaseType[]>;
    allCaseSeverities: IApiResponseDetails<ICaseSeverity[]>;
    allCaseStatuses: IApiResponseDetails<ICaseStatus[]>;
    allProducts: IApiResponseDetails<ITroubleshootProductResponse>;
    loggedInUsersAccount: IApiResponseDetails<Partial<IAccount>>;
    loggedInUsersAccountNumber: IApiResponseDetails<string>;
    loggedInUser: IApiResponseDetails<Partial<ISsoContact>>;
    loggedInUserJwtToken: Partial<IPortalJwtToken>;
    caseLanguages: IApiResponseDetails<string[]>;
    caseInternalStatuses: IApiResponseDetails<string[]>;
    caseGroups: IApiResponseDetails<ICaseGroup[]>;
    pcmConfig: IApiResponseDetails<IConfigurationResponse>;
    loggedInUserRights: IApiResponseDetails<UserAuth>;
    managedAccounts: IApiResponseDetails<Partial<IPartnerManagedAccount>[]>;
    accountManagers: IApiResponseDetails<Partial<IPartnerManagedAccount>[]>;
    bookmarkedAccounts: IApiResponseDetails<IAccount[]>;
    bookmarkedGroupAccounts: IApiResponseDetails<IBookmark[]>;
    caseSbrGroups: IApiResponseDetails<string[]>;
    userPreferences: IApiResponseDetails<IUserPreferences>;
    viewAsCustomer: boolean;
    navBarRef: MutableRefObject<HTMLElement>;
    hydraUserPreferences: IApiResponseDetails<IPreference[]>;
    featureFlags: IFeatureFlags;
    bookmarkedGroupIds: IBookmarkedGroupIds;
    accountCustomEmails: IApiResponseDetails<IAccountNotificationAddresses[]>;
    referrerUrl: string;
    caseNoClusterIdReasons: IApiResponseDetails<string[]>;
    caseListTraditionalSupportAgreed: boolean;
}
export interface IGlobalMetadataPayloadType extends IGlobalMetadataState {
    interaction: IIntraction;
    account: IAccount;
    flag: boolean;
}
type IActionType = IAction<GlobalMetadataReducerConstants, IGlobalMetadataPayloadType>;
export type GlobalMetadataReducerDispatchType = (value: IActionType) => void;
export declare const initialGlobalMetadataState: IGlobalMetadataState;
export declare const globalMetadataReducer: (pState: IGlobalMetadataState, action: IActionType) => IGlobalMetadataState;
export declare const setReferrerUrl: (dispatch: GlobalMetadataReducerDispatchType, referrerUrl: string) => void;
export declare const removeGroupedBookmarks: (dispatch: GlobalMetadataReducerDispatchType, allBookmarks: IBookmark[], removedAccountsId: number[]) => void;
export declare const removeWholeGroup: (dispatch: GlobalMetadataReducerDispatchType, allBookmarks: IBookmark[], rootBookmarIds: number[]) => void;
export declare const addEditbookmarks: (dispatch: GlobalMetadataReducerDispatchType, allBookmarks: IBookmark[], updatedAccounts: IBookmarkedAccounts, selectedAccounts: IBookmark[], group: string, accountsRemovedFromGroup?: IBookmark[]) => void;
export declare const fetchCaseTypes: (dispatch: GlobalMetadataReducerDispatchType, isSecureSupport: boolean) => Promise<void>;
export declare const fetchCaseSeverities: (dispatch: GlobalMetadataReducerDispatchType, isSecureSupport: boolean) => Promise<void>;
export declare const fetchAllStatuses: (dispatch: GlobalMetadataReducerDispatchType, isSecureSupport: boolean) => Promise<void>;
export declare const fetchProducts: (dispatch: GlobalMetadataReducerDispatchType, ownerSSOUsername?: string, params?: ISEProductListParams) => Promise<void>;
export declare const setAllProducts: (dispatch: GlobalMetadataReducerDispatchType, allProducts: ITroubleshootProductResponse) => void;
export declare const fetchLoggedInUsersAccount: (dispatch: GlobalMetadataReducerDispatchType, token: Partial<IPortalJwtToken>, silent?: boolean) => Promise<IAccount>;
export declare const fetchLoggedInUser: (dispatch: GlobalMetadataReducerDispatchType, token: Partial<IPortalJwtToken>, pcmConfig: any) => Promise<void>;
export declare const fetchLanguageMetadata: (dispatch: GlobalMetadataReducerDispatchType) => Promise<void>;
export declare const fetchInternalStatusMetadata: (dispatch: GlobalMetadataReducerDispatchType) => Promise<void>;
export declare const fetchCaseSbrsMetadata: (dispatch: GlobalMetadataReducerDispatchType) => Promise<void>;
export declare const fetchCaseGroupsForSSO: (dispatch: GlobalMetadataReducerDispatchType, ssoUserName: string) => Promise<ICaseGroup[]>;
export declare const fetchCaseGroups: (dispatch: GlobalMetadataReducerDispatchType) => Promise<void>;
export declare const setCaseGroups: (dispatch: GlobalMetadataReducerDispatchType, groups: ICaseGroup[]) => void;
export declare const setLoggedInUserJwtToken: (dispatch: GlobalMetadataReducerDispatchType, loggedInUserJwtToken: Partial<IPortalJwtToken>) => void;
export declare const loadPCMConfig: (dispatch: GlobalMetadataReducerDispatchType) => Promise<IConfigurationResponse>;
export declare const setLoggedInUserRoles: (dispatch: GlobalMetadataReducerDispatchType, loggedInUserRights: UserAuth) => void;
export declare const fetchManagedAccounts: (dispatch: GlobalMetadataReducerDispatchType, token: Partial<IPortalJwtToken>) => Promise<void>;
export declare const fetchAccountManagers: (dispatch: GlobalMetadataReducerDispatchType, token: Partial<IPortalJwtToken>) => Promise<void>;
export declare const fetchBookmarkedGroupAccounts: (dispatch: GlobalMetadataReducerDispatchType, username: string) => Promise<void>;
export declare const fetchBookmarkedAccounts: (dispatch: GlobalMetadataReducerDispatchType, bookmarkedAccounts: string[]) => Promise<void>;
export declare const setUserPreferences: (dispatch: GlobalMetadataReducerDispatchType, userPreferences: IUserPreferences) => void;
export declare const setNavbarRef: (dispatch: GlobalMetadataReducerDispatchType, navBarRef: MutableRefObject<HTMLElement>) => void;
export declare const toggleViewAsCustomerFlag: (dispatch: GlobalMetadataReducerDispatchType) => void;
export declare const fetchUserPreferences: (dispatch: GlobalMetadataReducerDispatchType, token: Partial<IPortalJwtToken>) => Promise<void>;
export declare const updateUserPreferences: (dispatch: GlobalMetadataReducerDispatchType, ssoUserName: string, preferences: IPreference[], operation?: "add" | "remove", silent?: boolean, throwAdditionalError?: boolean) => Promise<void>;
export declare const updateFeatureFlag: (dispatch: GlobalMetadataReducerDispatchType, featureFlags: Partial<IFeatureFlags>) => void;
export declare const fetchAccountCustomEmails: (dispatch: GlobalMetadataReducerDispatchType, accountNumber: string) => Promise<void>;
export declare const setAccountCustomEmails: (dispatch: GlobalMetadataReducerDispatchType, accountCustomEmails: IAccountNotificationAddresses[]) => void;
export declare const fetchNoClusterIdReasonsMetadata: (dispatch: GlobalMetadataReducerDispatchType) => Promise<void>;
export declare const updateCaseListTraditionalSupportAgreed: (dispatch: GlobalMetadataReducerDispatchType, value: boolean) => void;
export declare const updateShareHostnameWithRHTState: (dispatch: GlobalMetadataReducerDispatchType, loggedInUsersAccount: Partial<IAccount>, shareHostnameWithRHT: boolean) => void;
export {};
//# sourceMappingURL=GlobalMetadataReducer.d.ts.map