var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { accounts, caseMetadata, contacts, customEmail, maintenance, products, publicApi, userPreferences, } from '@cee-eng/hydrajs';
import { getApiResourceObject, handleEntitledProductResponse, handleProductSearchResponse, severitySort, } from '@rh-support/utils';
import differenceBy from 'lodash/differenceBy';
import filter from 'lodash/filter';
import find from 'lodash/find';
import isEmpty from 'lodash/isEmpty';
import reduce from 'lodash/reduce';
import sortBy from 'lodash/sortBy';
import unionBy from 'lodash/unionBy';
import { getProcessedCaseTypes } from './GlobalMetadataHelpers';
export var UserPreferencesKeys;
(function (UserPreferencesKeys) {
    UserPreferencesKeys["caseSavedSearchFilters"] = "PCM-CaseSavedSearchFilters";
    UserPreferencesKeys["commentType"] = "PCM-CommentType";
    UserPreferencesKeys["mostRecentSearch"] = "PCM-MostRecentSearch";
    UserPreferencesKeys["caseListSelectedColumns"] = "PCM-CaseListSelectedColumns";
    UserPreferencesKeys["featureAnnouncement"] = "PCM-FeatureAnnouncement";
    UserPreferencesKeys["autoRestoreSavedSearch"] = "PCM-AutoRestoreSavedSearch";
    UserPreferencesKeys["autoRestoreLastSearch"] = "PCM-AutoRestoreLastSearch";
    UserPreferencesKeys["autoSaveSelectedColumns"] = "PCM-AutoSaveSelectedColumns";
    UserPreferencesKeys["commentSignature"] = "PCM-CommentSignature";
    UserPreferencesKeys["shareHostnames"] = "PCM-ShareHostnames";
    UserPreferencesKeys["preferredLanguage"] = "PCM-PreferredLanguage";
    UserPreferencesKeys["defaultGroups"] = "PCM-DefaultGroup";
    UserPreferencesKeys["showHostnames"] = "PCM-showHostName";
    UserPreferencesKeys["showNewPreferenceTooltip"] = "PCM-prefToolTipVisibility";
    UserPreferencesKeys["caseViewInternal"] = "PCM-caseViewInternal";
    UserPreferencesKeys["partnershipLastestAcceptedLink"] = "PCM-PartnershipLastestAcceptedLink";
    UserPreferencesKeys["partnershipLastestRejectedLink"] = "PCM-PartnershipLastestRejectedLink";
    UserPreferencesKeys["userLastSavedABTest"] = "PCM-UserLastSavedABTest";
})(UserPreferencesKeys || (UserPreferencesKeys = {}));
export const BOOKMARK_APPLICATION_NAME = 'pcm';
export const BOOKMARK_NAME_SPACE = 'customer-portal';
export const BOOKMARK_TYPE = 'accountnumbers';
export var FeatureFlagKey;
(function (FeatureFlagKey) {
    FeatureFlagKey["tcSearch"] = "tcSearch";
})(FeatureFlagKey || (FeatureFlagKey = {}));
// Constants
export var GlobalMetadataReducerConstants;
(function (GlobalMetadataReducerConstants) {
    GlobalMetadataReducerConstants["setCaseTypes"] = "setCaseTypes";
    GlobalMetadataReducerConstants["setCaseSeverities"] = "setCaseSeverities";
    GlobalMetadataReducerConstants["setCaseStatuses"] = "setCaseStatuses";
    GlobalMetadataReducerConstants["setCaseEntitlements"] = "setCaseEntitlements";
    GlobalMetadataReducerConstants["setAllProducts"] = "setAllProducts";
    GlobalMetadataReducerConstants["setLoggedInUsersAccount"] = "setLoggedInUsersAccount";
    GlobalMetadataReducerConstants["setLoggedInUsersAccountNumber"] = "setLoggedInUsersAccountNumber";
    GlobalMetadataReducerConstants["setLoggedInUser"] = "setLoggedInUser";
    GlobalMetadataReducerConstants["setCaseLanguages"] = "setCaseLanguages";
    GlobalMetadataReducerConstants["setCaseGroups"] = "setCaseGroups";
    GlobalMetadataReducerConstants["setPcmConfig"] = "setPcmConfig";
    GlobalMetadataReducerConstants["setLoggedInUserJwtToken"] = "setLoggedInUserJwtToken";
    GlobalMetadataReducerConstants["setLoggedInUserRoles"] = "setLoggedInUserRoles";
    GlobalMetadataReducerConstants["setManagedAccounts"] = "setManagedAccounts";
    GlobalMetadataReducerConstants["setAccountManagers"] = "setAccountManagers";
    GlobalMetadataReducerConstants["getBookmarkedAccounts"] = "getBookmarkedAccounts";
    GlobalMetadataReducerConstants["updateGroupedBookmarks"] = "updateGroupedBookmarks";
    GlobalMetadataReducerConstants["removeGroupedBookmarks"] = "removeGroupedBookmarks";
    GlobalMetadataReducerConstants["getBookmarkedGroupAccounts"] = "getBookmarkedGroupAccounts";
    GlobalMetadataReducerConstants["bookmarkAdded"] = "bookmarkAdded";
    GlobalMetadataReducerConstants["bookmarkRemoved"] = "bookmarkRemoved";
    GlobalMetadataReducerConstants["setInternalStatuses"] = "setInternalStatuses";
    GlobalMetadataReducerConstants["setSbrGroups"] = "setSbrGroups";
    GlobalMetadataReducerConstants["setUserPreferences"] = "setUserPreferences";
    GlobalMetadataReducerConstants["toggleViewAsCustomer"] = "toggleViewAsCustomerFlag";
    GlobalMetadataReducerConstants["setNavbarRef"] = "setNavbarRef";
    GlobalMetadataReducerConstants["setHydraUserPreferences"] = "setHydraUserPreferences";
    GlobalMetadataReducerConstants["updateFeatureFlag"] = "updateFeatureFlag";
    GlobalMetadataReducerConstants["setAccountCustomEmails"] = "setAccountCustomEmails";
    GlobalMetadataReducerConstants["setReferrerUrl"] = "setReferrerUrl";
    GlobalMetadataReducerConstants["getNoclusteridreasons"] = "getNoclusteridreasons";
    GlobalMetadataReducerConstants["setIsSharingHostnameswithRHt"] = "setIsSharingHostnameswithRHt";
    GlobalMetadataReducerConstants["setCaseListTraditionalSupportAgreed"] = "setCaseListTraditionalSupportAgreed";
})(GlobalMetadataReducerConstants || (GlobalMetadataReducerConstants = {}));
const initialProductResponse = {
    topProducts: [],
    otherProducts: [],
    productsResult: [],
};
export const initialGlobalMetadataState = {
    allCaseTypes: getApiResourceObject([]),
    allCaseSeverities: getApiResourceObject([]),
    allCaseStatuses: getApiResourceObject([]),
    allProducts: getApiResourceObject(initialProductResponse),
    loggedInUsersAccount: getApiResourceObject({}),
    loggedInUsersAccountNumber: getApiResourceObject(),
    loggedInUser: getApiResourceObject({}),
    loggedInUserJwtToken: {},
    caseLanguages: getApiResourceObject([]),
    caseInternalStatuses: getApiResourceObject(),
    caseGroups: getApiResourceObject(),
    pcmConfig: getApiResourceObject([]),
    loggedInUserRights: getApiResourceObject({}, true),
    managedAccounts: getApiResourceObject(),
    accountManagers: getApiResourceObject(),
    bookmarkedAccounts: getApiResourceObject(),
    bookmarkedGroupAccounts: getApiResourceObject([]),
    caseSbrGroups: getApiResourceObject([]),
    accountCustomEmails: getApiResourceObject(),
    userPreferences: getApiResourceObject({ isCaseListFilterPanelExanded: true }),
    viewAsCustomer: false,
    navBarRef: null,
    hydraUserPreferences: getApiResourceObject([]),
    featureFlags: { [FeatureFlagKey.tcSearch]: false },
    bookmarkedGroupIds: {
        appId: undefined,
        namespaceId: undefined,
        valueTypeId: undefined,
    },
    referrerUrl: null,
    caseNoClusterIdReasons: getApiResourceObject([]),
    caseListTraditionalSupportAgreed: false,
};
// Resucers
export const globalMetadataReducer = (pState, action) => {
    var _a;
    switch (action.type) {
        case GlobalMetadataReducerConstants.setCaseTypes: {
            return Object.assign(Object.assign({}, pState), { allCaseTypes: action.payload.allCaseTypes });
        }
        case GlobalMetadataReducerConstants.setCaseSeverities: {
            return Object.assign(Object.assign({}, pState), { allCaseSeverities: action.payload.allCaseSeverities });
        }
        case GlobalMetadataReducerConstants.setCaseStatuses: {
            return Object.assign(Object.assign({}, pState), { allCaseStatuses: action.payload.allCaseStatuses });
        }
        case GlobalMetadataReducerConstants.setAllProducts: {
            return Object.assign(Object.assign({}, pState), { allProducts: action.payload.allProducts });
        }
        case GlobalMetadataReducerConstants.setLoggedInUsersAccount: {
            return Object.assign(Object.assign({}, pState), { loggedInUsersAccount: action.payload.loggedInUsersAccount });
        }
        case GlobalMetadataReducerConstants.setLoggedInUsersAccountNumber: {
            return Object.assign(Object.assign({}, pState), { loggedInUsersAccountNumber: action.payload.loggedInUsersAccountNumber });
        }
        case GlobalMetadataReducerConstants.setLoggedInUser: {
            return Object.assign(Object.assign({}, pState), { loggedInUser: action.payload.loggedInUser });
        }
        case GlobalMetadataReducerConstants.setCaseLanguages: {
            return Object.assign(Object.assign({}, pState), { caseLanguages: action.payload.caseLanguages });
        }
        case GlobalMetadataReducerConstants.setInternalStatuses: {
            return Object.assign(Object.assign({}, pState), { caseInternalStatuses: action.payload.caseInternalStatuses });
        }
        case GlobalMetadataReducerConstants.setCaseGroups: {
            return Object.assign(Object.assign({}, pState), { caseGroups: action.payload.caseGroups });
        }
        case GlobalMetadataReducerConstants.setPcmConfig: {
            return Object.assign(Object.assign({}, pState), { pcmConfig: action.payload.pcmConfig });
        }
        case GlobalMetadataReducerConstants.setLoggedInUserJwtToken: {
            return Object.assign(Object.assign({}, pState), { loggedInUserJwtToken: action.payload.loggedInUserJwtToken });
        }
        case GlobalMetadataReducerConstants.setLoggedInUserRoles: {
            return Object.assign(Object.assign({}, pState), { loggedInUserRights: action.payload.loggedInUserRights });
        }
        case GlobalMetadataReducerConstants.setManagedAccounts: {
            return Object.assign(Object.assign({}, pState), { managedAccounts: action.payload.managedAccounts });
        }
        case GlobalMetadataReducerConstants.setAccountManagers: {
            return Object.assign(Object.assign({}, pState), { accountManagers: action.payload.accountManagers });
        }
        case GlobalMetadataReducerConstants.getBookmarkedAccounts: {
            return Object.assign(Object.assign({}, pState), { bookmarkedAccounts: action.payload.bookmarkedAccounts });
        }
        case GlobalMetadataReducerConstants.getBookmarkedGroupAccounts: {
            return Object.assign(Object.assign({}, pState), { bookmarkedGroupAccounts: action.payload.bookmarkedGroupAccounts, bookmarkedGroupIds: action.payload.bookmarkedGroupIds });
        }
        case GlobalMetadataReducerConstants.bookmarkAdded: {
            const newBookmarkedAccounts = unionBy(pState.bookmarkedAccounts.data, [action.payload.account], 'accountNumber');
            return Object.assign(Object.assign({}, pState), { bookmarkedAccounts: getApiResourceObject(sortBy(newBookmarkedAccounts, 'name')) });
        }
        case GlobalMetadataReducerConstants.bookmarkRemoved: {
            const newBookmarkedAccounts = differenceBy(pState.bookmarkedAccounts.data, [action.payload.account], 'accountNumber');
            return Object.assign(Object.assign({}, pState), { bookmarkedAccounts: getApiResourceObject(newBookmarkedAccounts) });
        }
        case GlobalMetadataReducerConstants.setSbrGroups: {
            return Object.assign(Object.assign({}, pState), { caseSbrGroups: action.payload.caseSbrGroups });
        }
        case GlobalMetadataReducerConstants.setUserPreferences: {
            const updatedPreferences = Object.assign(Object.assign({}, pState.userPreferences.data), action.payload.userPreferences.data);
            return Object.assign(Object.assign({}, pState), { userPreferences: Object.assign(Object.assign({}, action.payload.userPreferences), { data: updatedPreferences }) });
        }
        case GlobalMetadataReducerConstants.toggleViewAsCustomer: {
            return Object.assign(Object.assign({}, pState), { viewAsCustomer: !pState.viewAsCustomer });
        }
        case GlobalMetadataReducerConstants.setNavbarRef: {
            return Object.assign(Object.assign({}, pState), { navBarRef: action.payload.navBarRef });
        }
        case GlobalMetadataReducerConstants.setHydraUserPreferences: {
            return Object.assign(Object.assign({}, pState), { hydraUserPreferences: Object.assign({}, action.payload.hydraUserPreferences) });
        }
        case GlobalMetadataReducerConstants.updateFeatureFlag: {
            const updatedFeatureFlags = Object.assign(Object.assign({}, pState.featureFlags), action.payload.featureFlags);
            return Object.assign(Object.assign({}, pState), { featureFlags: updatedFeatureFlags });
        }
        case GlobalMetadataReducerConstants.updateGroupedBookmarks: {
            return Object.assign(Object.assign({}, pState), { bookmarkedGroupAccounts: action.payload.bookmarkedGroupAccounts });
        }
        case GlobalMetadataReducerConstants.setAccountCustomEmails: {
            return Object.assign(Object.assign({}, pState), { accountCustomEmails: action.payload.accountCustomEmails });
        }
        case GlobalMetadataReducerConstants.setReferrerUrl: {
            return Object.assign(Object.assign({}, pState), { referrerUrl: action.payload.referrerUrl });
        }
        case GlobalMetadataReducerConstants.getNoclusteridreasons: {
            return Object.assign(Object.assign({}, pState), { caseNoClusterIdReasons: action.payload.caseNoClusterIdReasons });
        }
        case GlobalMetadataReducerConstants.setCaseListTraditionalSupportAgreed: {
            return Object.assign(Object.assign({}, pState), { caseListTraditionalSupportAgreed: (_a = action.payload) === null || _a === void 0 ? void 0 : _a.caseListTraditionalSupportAgreed });
        }
        default: {
            return pState;
        }
    }
};
export const setReferrerUrl = (dispatch, referrerUrl) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setReferrerUrl,
        payload: { referrerUrl },
    });
};
export const removeGroupedBookmarks = (dispatch, allBookmarks, removedAccountsId) => {
    const newBookmarksState = allBookmarks.filter((b) => !removedAccountsId.includes(b.bookmarkId));
    dispatch({
        type: GlobalMetadataReducerConstants.updateGroupedBookmarks,
        payload: { bookmarkedGroupAccounts: getApiResourceObject(newBookmarksState, false) },
    });
};
export const removeWholeGroup = (dispatch, allBookmarks, rootBookmarIds) => {
    const newBookmarksState = allBookmarks.filter((b) => !rootBookmarIds.includes(b.rootBookmarkId));
    dispatch({
        type: GlobalMetadataReducerConstants.updateGroupedBookmarks,
        payload: { bookmarkedGroupAccounts: getApiResourceObject(newBookmarksState, false) },
    });
};
export const addEditbookmarks = (dispatch, allBookmarks, updatedAccounts, selectedAccounts, group, accountsRemovedFromGroup) => {
    const updatedAccountIds = updatedAccounts && updatedAccounts.values.map((v) => v.id);
    const bookmarkIdsToBeRemoved = accountsRemovedFromGroup.map((a) => a.bookmarkId);
    const allBookmarksCopy = allBookmarks.filter((b) => !bookmarkIdsToBeRemoved.includes(b.bookmarkId));
    // update existing accounts with new ids and group
    updatedAccounts &&
        allBookmarksCopy.forEach((bookmark) => {
            if (updatedAccountIds.includes(bookmark.bookmarkId)) {
                bookmark.rootBookmarkId = updatedAccounts.id;
                bookmark.bookmarkGroupName = group || '';
                bookmark.bookmarkId = find(updatedAccounts.values, { value: bookmark.accountNumber }).id;
                bookmark.isBookmarkedAndHasGroup = !!updatedAccounts.name;
            }
        });
    // add new accounts to state - get account name from selected accounts
    updatedAccounts &&
        selectedAccounts.forEach((item) => {
            if (!item.bookmarkId || item.bookmarkGroupName !== group) {
                allBookmarksCopy.push({
                    rootBookmarkId: updatedAccounts.id,
                    bookmarkGroupName: group || '',
                    bookmarkId: find(updatedAccounts.values, { value: item.accountNumber }).id,
                    accountNumber: item.accountNumber,
                    name: item.name,
                    isBookmarked: true,
                    isBookmarkedAndHasGroup: !!updatedAccounts.name,
                    subscriptionAbuse: item.subscriptionAbuse,
                });
            }
        });
    dispatch({
        type: GlobalMetadataReducerConstants.updateGroupedBookmarks,
        payload: { bookmarkedGroupAccounts: getApiResourceObject(allBookmarksCopy, false) },
    });
};
export const fetchCaseTypes = (dispatch, isSecureSupport) => __awaiter(void 0, void 0, void 0, function* () {
    dispatch({
        type: GlobalMetadataReducerConstants.setCaseTypes,
        payload: { allCaseTypes: getApiResourceObject([], true) },
    });
    try {
        const caseTypes = yield caseMetadata.getTypes(isSecureSupport);
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseTypes,
            payload: { allCaseTypes: getApiResourceObject(getProcessedCaseTypes(caseTypes.items)) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseTypes,
            payload: { allCaseTypes: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchCaseSeverities = (dispatch, isSecureSupport) => __awaiter(void 0, void 0, void 0, function* () {
    dispatch({
        type: GlobalMetadataReducerConstants.setCaseSeverities,
        payload: { allCaseSeverities: getApiResourceObject([], true) },
    });
    try {
        const severities = yield caseMetadata.getSeverities(isSecureSupport);
        const allCaseSeverities = [...severities.items].sort((sevA, sevB) => severitySort(sevA, sevB));
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseSeverities,
            payload: { allCaseSeverities: getApiResourceObject(allCaseSeverities) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseSeverities,
            payload: { allCaseSeverities: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchAllStatuses = (dispatch, isSecureSupport) => __awaiter(void 0, void 0, void 0, function* () {
    dispatch({
        type: GlobalMetadataReducerConstants.setCaseStatuses,
        payload: { allCaseStatuses: getApiResourceObject([], true) },
    });
    try {
        const caseStatusesResponse = yield caseMetadata.getStatuses(isSecureSupport);
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseStatuses,
            payload: { allCaseStatuses: getApiResourceObject(caseStatusesResponse.items) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseStatuses,
            payload: { allCaseStatuses: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchProducts = (dispatch_1, ownerSSOUsername_1, ...args_1) => __awaiter(void 0, [dispatch_1, ownerSSOUsername_1, ...args_1], void 0, function* (dispatch, ownerSSOUsername, params = {}) {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setAllProducts,
            payload: { allProducts: getApiResourceObject(initialProductResponse, true) },
        });
        /**
         * Here we are trying to fetch products from two sources (getSEProductsList and getProducts) and if even first source (getSEProductsList) fail to deliver product information
         * we still need to use second source (getProducts) to parse and list product
         */
        const response = yield Promise.allSettled([
            products.getSEProductsList(params),
            products.getProducts(ownerSSOUsername),
        ]);
        const productsResultAll = response[0].status === 'fulfilled' ? response[0].value : [];
        const productsResultEntitled = response[1].status === 'fulfilled' ? response[1].value : [];
        const allProducts = productsResultAll.length
            ? handleProductSearchResponse(productsResultAll, productsResultEntitled)
            : handleEntitledProductResponse(productsResultEntitled);
        dispatch({
            type: GlobalMetadataReducerConstants.setAllProducts,
            payload: { allProducts: getApiResourceObject(allProducts) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setAllProducts,
            payload: { allProducts: getApiResourceObject(initialProductResponse, false, true, e.message) },
        });
    }
});
export const setAllProducts = (dispatch, allProducts) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setAllProducts,
        payload: { allProducts: getApiResourceObject(allProducts) },
    });
};
export const fetchLoggedInUsersAccount = (dispatch_1, token_1, ...args_1) => __awaiter(void 0, [dispatch_1, token_1, ...args_1], void 0, function* (dispatch, token, silent = false) {
    var _a;
    let accountNumber = token.account_number;
    if (silent) {
        try {
            const loggedInUsersAccount = yield accounts.getAccount(accountNumber);
            dispatch({
                type: GlobalMetadataReducerConstants.setLoggedInUsersAccount,
                payload: { loggedInUsersAccount: getApiResourceObject(loggedInUsersAccount) },
            });
        }
        catch (e) {
            // if it fails we don't override the old account details
        }
    }
    else {
        try {
            dispatch({
                type: GlobalMetadataReducerConstants.setLoggedInUsersAccount,
                payload: { loggedInUsersAccount: getApiResourceObject({}, true) },
            });
            const loggedInUsersAccount = yield accounts.getAccount(accountNumber);
            dispatch({
                type: GlobalMetadataReducerConstants.setLoggedInUsersAccount,
                payload: { loggedInUsersAccount: getApiResourceObject(loggedInUsersAccount) },
            });
            return loggedInUsersAccount;
        }
        catch (e) {
            (_a = window.sessionjs) === null || _a === void 0 ? void 0 : _a.reportProblem(e, {
                tags: {
                    portal_app: window.app || 'Portal Case Management',
                    error_effect: 'PCM - App wide error',
                },
                fingerprint: 'PCM - App wide error',
                extra: { errorDetails: `App wide error due to getAccountDetails with status ${e === null || e === void 0 ? void 0 : e.status}` },
            });
            dispatch({
                type: GlobalMetadataReducerConstants.setLoggedInUsersAccount,
                payload: { loggedInUsersAccount: getApiResourceObject({}, false, true, e === null || e === void 0 ? void 0 : e.message, e) },
            });
        }
    }
});
export const fetchLoggedInUser = (dispatch, token, pcmConfig) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setLoggedInUser,
            payload: { loggedInUser: getApiResourceObject({}, true) },
        });
        let loggedInUser = yield contacts.getCurrentContact({
            userId: token.user_id,
            assumeEntitledIfSubscriptionServiceUnavailable: true,
        });
        dispatch({
            type: GlobalMetadataReducerConstants.setLoggedInUser,
            payload: { loggedInUser: getApiResourceObject(loggedInUser) },
        });
        // Saving bookmarked accounts separately.
        const canViewBookmarkAccounts = loggedInUser.isInternal;
        if (canViewBookmarkAccounts) {
            fetchBookmarkedGroupAccounts(dispatch, loggedInUser.ssoUsername);
        }
    }
    catch (e) {
        (_a = window.sessionjs) === null || _a === void 0 ? void 0 : _a.reportProblem(e, {
            tags: {
                portal_app: window.app || 'Portal Case Management',
                error_effect: 'PCM - App wide error',
            },
            fingerprint: 'PCM - App wide error',
            extra: {
                errorDetails: `App wide error due to getStrataUser`,
            },
        });
        dispatch({
            type: GlobalMetadataReducerConstants.setLoggedInUser,
            payload: { loggedInUser: getApiResourceObject({}, false, true, e.message) },
        });
    }
});
export const fetchLanguageMetadata = (dispatch) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseLanguages,
            payload: { caseLanguages: getApiResourceObject([], true) },
        });
        const response = yield caseMetadata.getLanguagesMetadata();
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseLanguages,
            payload: { caseLanguages: getApiResourceObject(response.items) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseLanguages,
            payload: { caseLanguages: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchInternalStatusMetadata = (dispatch) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setInternalStatuses,
            payload: { caseInternalStatuses: getApiResourceObject([], true) },
        });
        const response = yield caseMetadata.getInternalStatusMetadata();
        dispatch({
            type: GlobalMetadataReducerConstants.setInternalStatuses,
            payload: { caseInternalStatuses: getApiResourceObject(response.items) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setInternalStatuses,
            payload: { caseInternalStatuses: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchCaseSbrsMetadata = (dispatch) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setSbrGroups,
            payload: { caseSbrGroups: getApiResourceObject([], true) },
        });
        const response = yield caseMetadata.getCaseSbrs();
        dispatch({
            type: GlobalMetadataReducerConstants.setSbrGroups,
            payload: { caseSbrGroups: getApiResourceObject(response.items) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setSbrGroups,
            payload: { caseSbrGroups: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchCaseGroupsForSSO = (dispatch, ssoUserName) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseGroups,
            payload: { caseGroups: getApiResourceObject([], true) },
        });
        const response = yield publicApi.caseGroups.getCaseGroupsForSSO(ssoUserName);
        (response || []).sort((a, b) => a.name.localeCompare(b.name));
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseGroups,
            payload: { caseGroups: getApiResourceObject(response, false) },
        });
        return response;
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseGroups,
            payload: { caseGroups: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchCaseGroups = (dispatch) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseGroups,
            payload: { caseGroups: getApiResourceObject([], true) },
        });
        const response = yield publicApi.caseGroups.getCaseGroups();
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseGroups,
            payload: { caseGroups: getApiResourceObject(response, false) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setCaseGroups,
            payload: { caseGroups: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const setCaseGroups = (dispatch, groups) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setCaseGroups,
        payload: { caseGroups: getApiResourceObject(groups, false) },
    });
};
export const setLoggedInUserJwtToken = (dispatch, loggedInUserJwtToken) => {
    dispatch({ type: GlobalMetadataReducerConstants.setLoggedInUserJwtToken, payload: { loggedInUserJwtToken } });
};
export const loadPCMConfig = (dispatch) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setPcmConfig,
            payload: { pcmConfig: getApiResourceObject([], true) },
        });
        const pcmConfig = (yield maintenance.getHydraConfiguration('pcm_configurations')) || [];
        dispatch({
            type: GlobalMetadataReducerConstants.setPcmConfig,
            payload: { pcmConfig: getApiResourceObject(pcmConfig) },
        });
        return pcmConfig;
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setPcmConfig,
            payload: { pcmConfig: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const setLoggedInUserRoles = (dispatch, loggedInUserRights) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setLoggedInUserRoles,
        payload: { loggedInUserRights: getApiResourceObject(loggedInUserRights) },
    });
};
export const fetchManagedAccounts = (dispatch, token) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setManagedAccounts,
            payload: { managedAccounts: getApiResourceObject([], true) },
        });
        const managedAccounts = yield accounts.getCustomerAccountsForAPartner(token.account_number, null, true);
        dispatch({
            type: GlobalMetadataReducerConstants.setManagedAccounts,
            payload: {
                managedAccounts: getApiResourceObject(!isEmpty(managedAccounts) ? sortBy(managedAccounts.accounts, 'name') : []),
            },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setManagedAccounts,
            payload: { managedAccounts: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchAccountManagers = (dispatch, token) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setAccountManagers,
            payload: { accountManagers: getApiResourceObject([], true) },
        });
        const accountManagers = yield accounts.getPartnerAccountsForACustomer(token.account_number, null, true);
        dispatch({
            type: GlobalMetadataReducerConstants.setAccountManagers,
            payload: {
                accountManagers: getApiResourceObject(!isEmpty(accountManagers) ? accountManagers.accounts : []),
            },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setAccountManagers,
            payload: { accountManagers: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const fetchBookmarkedGroupAccounts = (dispatch, username) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b, _c;
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.getBookmarkedGroupAccounts,
            payload: { bookmarkedGroupAccounts: getApiResourceObject([], true), bookmarkedGroupIds: undefined },
        });
        const [bookmarkedAccounts, bookmarkAppData] = yield Promise.all([
            yield publicApi.utilsBookmark.getBookmarks({
                valueType: BOOKMARK_TYPE,
                namespace: BOOKMARK_NAME_SPACE,
                username,
            }),
            publicApi.utilsBookmark.getAppData(),
        ]);
        const bookmarkedGroupIds = {
            appId: (_a = bookmarkAppData['apps'].find((item) => item.name === BOOKMARK_APPLICATION_NAME)) === null || _a === void 0 ? void 0 : _a.id,
            namespaceId: (_b = bookmarkAppData['namespaces'].find((item) => item.name === BOOKMARK_NAME_SPACE)) === null || _b === void 0 ? void 0 : _b.id,
            valueTypeId: (_c = bookmarkAppData['valueTypes'].find((item) => item.name === BOOKMARK_TYPE)) === null || _c === void 0 ? void 0 : _c.id,
        };
        const getAllAccountNumbers = reduce(bookmarkedAccounts, (acc, item) => {
            const idsInOneBookmakedObj = item.values.map((v) => v.value);
            return [...acc, ...idsInOneBookmakedObj];
        }, []);
        const fields = ['accountNumber', 'accountId', 'name', 'subscriptionAbuse'].join(',');
        const params = {
            fields,
            orderBy: 'name',
            orderDirection: 'asc',
            accountNumberIn: getAllAccountNumbers.join(','),
        };
        const accountsDetail = yield accounts.getAccounts(params);
        const accountObjMap = {};
        accountsDetail.items.forEach((item) => (accountObjMap[item.accountNumber] = {
            name: item.name || '',
            subscriptionAbuse: item.subscriptionAbuse || false,
        }));
        const bookmarks = [];
        for (let i = 0, len = bookmarkedAccounts.length; i < len; i++) {
            for (let j = 0, vLen = bookmarkedAccounts[i].values.length; j < vLen; j++) {
                if (accountObjMap[bookmarkedAccounts[i].values[j].value]) {
                    const bookmark = {
                        rootBookmarkId: bookmarkedAccounts[i].id,
                        bookmarkGroupName: bookmarkedAccounts[i].name || '',
                        bookmarkId: bookmarkedAccounts[i].values[j].id,
                        accountNumber: bookmarkedAccounts[i].values[j].value,
                        name: accountObjMap[bookmarkedAccounts[i].values[j].value].name,
                        isBookmarked: true,
                        isBookmarkedAndHasGroup: !!bookmarkedAccounts[i].name,
                        subscriptionAbuse: accountObjMap[bookmarkedAccounts[i].values[j].value].subscriptionAbuse,
                    };
                    bookmarks.push(bookmark);
                }
            }
        }
        dispatch({
            type: GlobalMetadataReducerConstants.getBookmarkedGroupAccounts,
            payload: { bookmarkedGroupAccounts: getApiResourceObject(bookmarks), bookmarkedGroupIds },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.getBookmarkedGroupAccounts,
            payload: {
                bookmarkedGroupAccounts: getApiResourceObject([], false, true, e.message),
                bookmarkedGroupIds: undefined,
            },
        });
    }
});
export const fetchBookmarkedAccounts = (dispatch, bookmarkedAccounts) => __awaiter(void 0, void 0, void 0, function* () {
    if (isEmpty(bookmarkedAccounts))
        return;
    const fields = ['accountNumber', 'accountId', 'name'].join(',');
    // Initialize Params
    const params = {
        fields,
        orderBy: 'name',
        orderDirection: 'asc',
        accountNumberIn: bookmarkedAccounts.join(','),
    };
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.getBookmarkedAccounts,
            payload: { bookmarkedAccounts: getApiResourceObject([], true) },
        });
        const response = yield accounts.getAccounts(params);
        response &&
            !isEmpty(response.items) &&
            dispatch({
                type: GlobalMetadataReducerConstants.getBookmarkedAccounts,
                payload: { bookmarkedAccounts: getApiResourceObject(response.items) },
            });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.getBookmarkedAccounts,
            payload: { bookmarkedAccounts: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const setUserPreferences = (dispatch, userPreferences) => {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setUserPreferences,
            payload: { userPreferences: getApiResourceObject(userPreferences) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setUserPreferences,
            payload: { userPreferences: getApiResourceObject({}, false, true, e.message) },
        });
    }
};
export const setNavbarRef = (dispatch, navBarRef) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setNavbarRef,
        payload: { navBarRef },
    });
};
export const toggleViewAsCustomerFlag = (dispatch) => {
    dispatch({ type: GlobalMetadataReducerConstants.toggleViewAsCustomer });
};
export const fetchUserPreferences = (dispatch, token) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setHydraUserPreferences,
            payload: { managedAccounts: getApiResourceObject([], true) },
        });
        const preferences = yield userPreferences.getUserPreferences(token.username);
        dispatch({
            type: GlobalMetadataReducerConstants.setHydraUserPreferences,
            payload: {
                hydraUserPreferences: getApiResourceObject(preferences ? filter(preferences, (preference) => preference.key.startsWith('PCM')) : []),
            },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setHydraUserPreferences,
            payload: { hydraUserPreferences: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const updateUserPreferences = (dispatch_1, ssoUserName_1, preferences_1, ...args_1) => __awaiter(void 0, [dispatch_1, ssoUserName_1, preferences_1, ...args_1], void 0, function* (dispatch, ssoUserName, preferences, operation = 'add', silent = false, throwAdditionalError) {
    try {
        !silent &&
            dispatch({
                type: GlobalMetadataReducerConstants.setHydraUserPreferences,
                payload: { hydraUserPreferences: getApiResourceObject([], true) },
            });
        const updatedPreferences = yield userPreferences.updateUserPreferences(ssoUserName, [
            {
                path: 'preferences',
                op: operation,
                value: preferences,
            },
        ]);
        dispatch({
            type: GlobalMetadataReducerConstants.setHydraUserPreferences,
            payload: {
                hydraUserPreferences: getApiResourceObject(updatedPreferences
                    ? filter(updatedPreferences, (preference) => preference.key.startsWith('PCM'))
                    : []),
            },
        });
    }
    catch (e) {
        !silent &&
            dispatch({
                type: GlobalMetadataReducerConstants.setHydraUserPreferences,
                payload: { hydraUserPreferences: getApiResourceObject([], false, true, e.message) },
            });
        if (throwAdditionalError)
            throw e;
    }
});
export const updateFeatureFlag = (dispatch, featureFlags) => {
    dispatch({
        type: GlobalMetadataReducerConstants.updateFeatureFlag,
        payload: { featureFlags },
    });
};
export const fetchAccountCustomEmails = (dispatch, accountNumber) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        dispatch({
            type: GlobalMetadataReducerConstants.setAccountCustomEmails,
            payload: { accountCustomEmails: getApiResourceObject([], true) },
        });
        const res = yield customEmail.getCustomEmailsFromAccount(accountNumber);
        dispatch({
            type: GlobalMetadataReducerConstants.setAccountCustomEmails,
            payload: { accountCustomEmails: getApiResourceObject(res.notificationAddresses) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.setAccountCustomEmails,
            payload: { accountCustomEmails: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const setAccountCustomEmails = (dispatch, accountCustomEmails) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setAccountCustomEmails,
        payload: { accountCustomEmails: getApiResourceObject(accountCustomEmails, false) },
    });
};
export const fetchNoClusterIdReasonsMetadata = (dispatch) => __awaiter(void 0, void 0, void 0, function* () {
    dispatch({
        type: GlobalMetadataReducerConstants.getNoclusteridreasons,
        payload: { caseNoClusterIdReasons: getApiResourceObject([], true) },
    });
    try {
        const getNoClusterIdReasons = yield caseMetadata.getNoClusterIdReasons();
        dispatch({
            type: GlobalMetadataReducerConstants.getNoclusteridreasons,
            payload: { caseNoClusterIdReasons: getApiResourceObject(getNoClusterIdReasons.items) },
        });
    }
    catch (e) {
        dispatch({
            type: GlobalMetadataReducerConstants.getNoclusteridreasons,
            payload: { caseNoClusterIdReasons: getApiResourceObject([], false, true, e.message) },
        });
    }
});
export const updateCaseListTraditionalSupportAgreed = (dispatch, value) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setCaseListTraditionalSupportAgreed,
        payload: { caseListTraditionalSupportAgreed: value },
    });
};
export const updateShareHostnameWithRHTState = (dispatch, loggedInUsersAccount, shareHostnameWithRHT) => {
    dispatch({
        type: GlobalMetadataReducerConstants.setLoggedInUsersAccount,
        payload: { loggedInUsersAccount: getApiResourceObject(Object.assign(Object.assign({}, loggedInUsersAccount), { shareHostnameWithRHT })) },
    });
};
